Module debug_info

Module debug_info 

Debug information which is parsed from DWARF debugging information.

Structs

DebugInfo
Debug information which is parsed from DWARF debugging information.

Functions

determine_cfa
Determines the CFA (canonical frame address) for the current gimli::UnwindTableRow, using the current register values.
get_unwind_info
Get a handle to the gimli::UnwindTableRow for this call frame, so that we can reference it to unwind register values.
unwind_pc_without_debuginfo
Unwind the program counter for the caller frame, using the LR value from the callee frame.
unwind_program_counter_register
Helper function to determine the program counter value for the previous frame.
unwind_register
A per_register unwind, applying register rules and updating the [registers::DebugRegister] value as appropriate, before returning control to the calling function.