pub struct DebugRegister {
pub core_register: &'static CoreRegister,
pub dwarf_id: Option<u16>,
pub value: Option<RegisterValue>,
}Expand description
Stores the relevant information from [crate::core::CoreRegister] for use in debug operations,
as well as additional information required during debug.
Fields
core_register: &'static CoreRegisterTo lookup platform specific details of core register definitions.
dwarf_id: Option<u16>DWARF specification, section 2.6.1.1.3.1 “… operations encode the names of up to 32 registers, numbered from 0 through 31, inclusive …”
value: Option<RegisterValue>The value of the register is read from the target memory and updated as needed.
Implementations
Sourceimpl DebugRegister
impl DebugRegister
Sourcepub fn memory_range(&self) -> Result<Option<Range<u64>>, Error>
pub fn memory_range(&self) -> Result<Option<Range<u64>>, Error>
Return the memory range required to read the register value.
Sourcepub fn get_register_name(&self) -> String
pub fn get_register_name(&self) -> String
Retrieve the name of the CoreRegister role if it exists, else the name.