DebugRegisters

Struct DebugRegisters 

pub struct DebugRegisters(pub Vec<DebugRegister>);
All the registers required for debug related operations.

Tuple Fields

0: Vec<DebugRegister>

Implementations

Source

impl DebugRegisters

pub fn from_core(core: &mut impl CoreInterface) -> Self

Read all registers defined in [probe_rs::core::CoreRegisters] from the given core.

pub fn from_coredump(core: &CoreDump) -> Self

Read all registers captured in the given CoreDump.

pub fn get_address_size_bytes(&self) -> usize

Gets the address size for this target, in bytes

pub fn address_to_register_value(&self, address: u64) -> RegisterValue

Wraps a program address in a RegisterValue of the target’s address size, so that its printed width is consistent across all stack frames. A plain RegisterValue::from(u64) would always yield a U64, printing 16 hex digits on 32-bit targets.

pub fn get_frame_pointer(&self) -> Option<&DebugRegister>

Get the canonical frame address, as specified in the DWARF specification, section 6.4. DWARF

This is not always available

pub fn get_program_counter<'b, 'c: 'b>(&'c self) -> Option<&'b DebugRegister>

Get the program counter.

pub fn get_program_counter_mut<'b, 'c: 'b>( &'c mut self, ) -> Option<&'b mut DebugRegister>

Get a mutable reference to the program counter.

pub fn get_stack_pointer(&self) -> Option<&DebugRegister>

Get the stack pointer.

pub fn get_return_address(&self) -> Option<&DebugRegister>

Get the return address.

pub fn get_register(&self, register_id: RegisterId) -> Option<&DebugRegister>

Get a register by RegisterId

pub fn get_register_mut( &mut self, register_id: RegisterId, ) -> Option<&mut DebugRegister>

Get a mutable reference register by RegisterId

pub fn get_register_by_dwarf_id(&self, dwarf_id: u16) -> Option<&DebugRegister>

Get the register value using the positional index into core registers. DWARF specification, section 2.6.1.1.3.1 “… operations encode the names of up to 32 registers, numbered from 0 through 31, inclusive …”

pub fn get_register_name(&self, register_id: RegisterId) -> String

Retrieve the role name if it exists, else the actual name using the RegisterId as an identifier.

pub fn get_register_by_role( &self, register_role: &RegisterRole, ) -> Result<&DebugRegister, Error>

Retrieve a reference to a register by searching against an exact match of the RegisterRole.

pub fn get_register_value_by_role( &self, register_role: &RegisterRole, ) -> Result<u64, Error>

Retrieve the stored value of a register by searching against an exact match of the RegisterRole.

pub fn get_register_mut_by_role( &mut self, register_role: &RegisterRole, ) -> Result<&mut DebugRegister, Error>

Retrieve a mutable reference to a register by searching against an exact match of the RegisterRole.

pub fn get_register_by_name(&self, register_name: &str) -> Option<DebugRegister>

Retrieve a register by searching against either the name or the role name. Use this for registers that have platform specific names like “t1”, or “s9”, etc., and cannot efficiently be accessed through any of the other methods.