Module stack_frame

Module stack_frame 

The stack frame information used while unwinding the stack from a specific program counter.

Structs

StackFrame
A full stack frame with all its information contained.
StackFrameInfo
Helper struct to pass around multiple pieces of StackFrame related information.