Module variable

Variable information used during debug.

Structs

Bitfield
Bitfield information for a variable.
Variable
The Variable struct is used in conjunction with VariableCache to cache data about variables.

Enums

BitOffset
The starting bit (and direction) of a bit field type.
Modifier
A modifier to a variable type. Currently only used to format the type name.
VariableLocation
Location of a variable
VariableName
The type of variable we have at hand.
VariableNodeType
Encode the nature of the Debug Information Entry in a way that we can resolve child nodes of a Variable.
VariableType
The variants of VariableType allows us to streamline the conditional logic that requires specific handling depending on the nature of the variable.
VariableValue
A Variable will have either a valid value, or some reason why a value could not be constructed.
VariantRole
Define the role that a variable plays in a Variant relationship. See section ‘5.7.10 Variant Entries’ of the DWARF 5 specification