Module variable_cache

The hierarchical cache of all variables for a given scope.

Structs

VariableCache
VariableCache stores available Variables, and provides methods to create and navigate the parent-child relationships of the Variables.