Debug information which is parsed from DWARF debugging information.
Structs
- Debug
Info - Debug information which is parsed from DWARF debugging information.
Functions
- determine_
cfa - Determines the CFA (canonical frame address) for the current
gimli::UnwindTableRow, using the current register values. - get_
unwind_ info - Get a handle to the
gimli::UnwindTableRowfor this call frame, so that we can reference it to unwind register values. - unwind_
pc_ without_ debuginfo - Unwind the program counter for the caller frame, using the LR value from the callee frame.
- unwind_
program_ counter_ register - Helper function to determine the program counter value for the previous frame.
- unwind_
register - A per_register unwind, applying register rules and updating the [
registers::DebugRegister] value as appropriate, before returning control to the calling function.