pub fn unwind_register(
debug_register: &DebugRegister,
callee_frame_registers: &DebugRegisters,
unwind_info: &UnwindTableRow<<EndianReader<RunTimeEndian, Rc<[u8]>> as Reader>::Offset>,
unwind_cfa: Option<u64>,
memory: &mut dyn MemoryInterface,
exception_handler: &dyn ExceptionInterface,
) -> Result<Option<RegisterValue>, Error>Expand description
A per_register unwind, applying register rules and updating the [registers::DebugRegister] value as appropriate, before returning control to the calling function.