The stack frame information used while unwinding the stack from a specific program counter.
Structs
- Stack
Frame - A full stack frame with all its information contained.
- Stack
Frame Info - Helper struct to pass around multiple pieces of
StackFramerelated information.