Variable information used during debug.
Structs
- Bitfield
- Bitfield information for a variable.
- Variable
- The
Variablestruct is used in conjunction withVariableCacheto cache data about variables.
Enums
- BitOffset
- The starting bit (and direction) of a bit field type.
- Modifier
- A modifier to a variable type. Currently only used to format the type name.
- Variable
Location - Location of a variable
- Variable
Name - The type of variable we have at hand.
- Variable
Node Type - Encode the nature of the Debug Information Entry in a way that we can resolve child nodes of a Variable.
- Variable
Type - The variants of VariableType allows us to streamline the conditional logic that requires specific handling depending on the nature of the variable.
- Variable
Value - A Variable will have either a valid value, or some reason why a value could not be constructed.
- Variant
Role - Define the role that a variable plays in a Variant relationship. See section ‘5.7.10 Variant Entries’ of the DWARF 5 specification