The hierarchical cache of all variables for a given scope.
Structs
- Variable
Cache - VariableCache stores available
Variables, and provides methods to create and navigate the parent-child relationships of the Variables.
The hierarchical cache of all variables for a given scope.
Variables, and provides methods to create and navigate the parent-child relationships of the Variables.